function [T,psi] = solve_rlcircuit(my_ctx)

  %..Compute initial condition taking phase shift into account.. 
  Rpre    = 5; Rpost = .1; R_init = Rpre+Rpost; Tfault = 1; Vmax = 28;    
  L_init  = lookup_imped(0,my_ctx);
  om      = 2*pi*50;  
  X_init  = sqrt(R_init^2 + om^2*L_init^2);  
  phase_shift = atan(om*R_init/L_init); 
  I_init   = - Vmax/X_init*sin(phase_shift); 
  psi_init =  L_init*I_init;

  %..Add DC component.. 
  V_dc = -.4; 
  psi_dc = L_init*V_dc/R_init;  

  %..Solve ODE for the magnetic flux.. 
  Tend    = 0.32;
  options = odeset('RelTol',1e-12,'AbsTol',1e-12);
%  options = []; 
  [T,psi] = ode45(@rlcircuit,[0 Tend],psi_init+psi_dc,options);

  function dpsidt = rlcircuit(t,psi)

    if (t<Tfault) Rline = Rpre+Rpost; else Rline = Rpost; end 
    Vline  = V_dc + Vmax*sin(2*pi*50*t); 
    Limpd  = lookup_imped(psi,my_ctx);
    dpsidt = Vline - Rline/Limpd*psi;

    end 

  end 
