  flclear fem femdcstart femacstart femac  
  close all 

  %..Set switches.. 
  bhswtch = 'linear'; 

  %..Set current and number of turns constants
  Idc  = 10; 
  dcNt = 170; 
  acNt = 170; 

  %..================================================================
  %..== Create geometery                                           ==
  %..================================================================
  %..Depth D  in x-direction 
  %..Width W  in y-direction 
  %..Height H in z-direction 
  %..================================================================
  %..== Dimensions of core (including rounding), ac and dc coils   ==
  %..== and air                                                    ==
  %..================================================================
  %..Core and windows  
  crwout    = 64e-3; 
  crhout    = 65e-3;
  crwindin  = 13e-3;
  crwindout = 38e-3;
  crwleg    = crwout - crwindout; 
  crhin     = 39e-3;
  crd       = 12.5e-3; 
  rad       = 5e-3; 
  gapw      = crwindin; 
  gaph      = 1.75e-3;

  %..AC and DC coils   
  coilh = 35e-3;  
  coilw = 20e-3;
  coilhshift = crhin/2 - coilh/2;
  coilwshift = crwout-crwleg/2; 
  coilwin    = crwleg/2; coilwout = coilwin+coilw; 
  coildin    = crd; coildout = coildin+coilw; 
 
  %..Air 
  aird = 600e-3; 
  airw = 600e-3; 
  airh = 600e-3; 
  %..================================================================
  %..== Core                                                       ==
  %..================================================================  
  windr      = fillet(rect2(crwindin,crwindout,-crhin,crhin),'radii',rad); 
  windl      = move(windr,-51e-3,0); 
  gap        = rect2(-gapw,gapw,-gaph,gaph); 
  core_plane = fillet(rect2(-crwout,crwout,-crhout,crhout),'radii',rad)...
               - windr - windl - gap; 
  %....Create work plane in DW plane.... 
  p_wrkpln = geomgetwrkpln('quick',{'yz',-crd});
  %....Extrude in heigt direction.... 
  core = extrude(core_plane, 'wrkpln',p_wrkpln, 'distance',2*crd);
  %..================================================================
  %..== AC and DC Coils                                            ==
  %..================================================================  
  coil_plane = fillet(rect2(-coildout,coildout,-coilwout,coilwout),'radii',rad) ...
               -  rect2(-coildin,coildin,-coilwin,coilwin);
  coil_plane = circ2(32e-3) - circ2(22e-3); 
  coil_yc    = 51.5e-3; 
  %....Create work plane in DW plane.... 
  p_wrkpln = geomgetwrkpln('quick',{'xy',coilhshift/2});
  %....Extrude in heigt direction.... 
  coil   = extrude(coil_plane, 'wrkpln',p_wrkpln, 'distance',coilh); 
  dccoil1 = move(coil,0,-coil_yc,0); 
  dccoil2 = move(dccoil1,0,crwout+crwindout,0); 
  accoil1 = move(dccoil1,0,0,-2*coilhshift-coilh+2e-3); 
  accoil2 = move(dccoil2,0,0,-2*coilhshift-coilh+2e-3); 

  %..================================================================
  %..== Air                                                        ==
  %..================================================================  
  %....Extrude in depth direction.... 
  air = block3(airh/2,airh,airh,'base','center','pos',[airh/4 0 0]);  
  %..================================================================
  %..== Reduce geometry by exploiting symmetry                     ==
  %..================================================================  
  core     = core*air; 
  dccoil1  = dccoil1*air; 
  dccoil2  = dccoil2*air; 
  accoil1  = accoil1*air; 
  accoil2  = accoil2*air; 

  % Analyzed geometry
  clear draw
  draw.s.objs={core,dccoil1,dccoil2,accoil1,accoil2,air};
  draw.s.name={'core','dccoil1','dccoil2','accoil1','accoil2','air'};
  draw.s.tags={'g1','g2','g3','g4','g5','g6'};

  fem.draw=draw;
  fem.geom=geomcsg(fem);
 
  if (1)
    geomplot(core+dccoil1+accoil1+dccoil2+accoil2,'facemode','off')
    return 
  end

  fem.const = {'om',              2*pi*50,...
               'flcoilh',         coilw,...
               'flcoilw',         coilh,...
               'flcoil_yc',       coil_yc,... 
               'accross',         coilw*coilh,...
               'dccross',         coilw*coilh,...  
               'ac_fill',         1,...
               'dc_fill',         1,...
               'Iamp',            5,...  
               'flIdc',           Idc,...
               'fldcNt',          dcNt,... 
               'flacNt',          acNt,... 
               'linmurfe',        '1000',... 
               'bha',             '2.12e-4',...
               'bhb',             '7.358',...
               'bhc',             '1.18e6',...
               'C1',              '.25',...
               'C2',              '.06'}; 

  % Functions
  clear fcns
  fcns{1}.type='inline';
  fcns{1}.name='murfe(x,bha,bhb,bhc)';
  fcns{1}.expr='1/(bha + (1-bha)*x^bhb/(x^bhb+bhc))';
  fcns{1}.dexpr={'diff(1/(bha+(1-bha)*x^bhb/ (x^bhb+bhc)),x)',...
                 '0','0','0'};
  fcns{2}.type='inline';
  fcns{2}.name='murfe2(x,C1,C2)';
  fcns{2}.expr='1/(C1*C2*cosh(C2*x))';
  fcns{2}.dexpr={'diff(1/(C1*C2*cosh(C2*x)),x)','0','0'};
  fcns{3}.type='inline';
  fcns{3}.name='mur_a(x,C1,C2)';
  fcns{3}.expr='C2*x/(4*pi*1e-7*sinh(x/C1))';
  fcns{3}.dexpr={'diff(C2*x/(4*pi*1e-7*sinh(x/C1)),x)','0','0'};
  fcns{4}.type='interp';
  fcns{4}.name='bmurtabular';
  fcns{4}.method='linear';
  fcns{4}.extmethod='const';
  fcns{4}.filename='/mnt/dutita1/nw/domenico/software/bh_curve/mur_normb_data.txt';
  fcns{5}.type='inline';
  fcns{5}.name='dlbhfct(x)';
  fcns{5}.expr='3000 - (3000-10)*flc2hs(x-1.8,.2)';
  fcns{5}.dexpr={'diff(3000 - (3000-10)*flc2hs(x-1.8,.7),x)'};
  fcns{6}.type='inline';
  fcns{6}.name='Wx(x,y,ynull)';
  fcns{6}.expr='(y-ynull)/sqrt(x^2+(y-ynull)^2)'; 
  fcns{6}.dexpr={'0','0','0'};
  fcns{7}.type='inline';
  fcns{7}.name='Wy(x,y,ynull)';
  fcns{7}.expr='-x/sqrt(x^2+(y-ynull)^2)';
  fcns{7}.dexpr={'0','0','0'};

  fem.functions = fcns;


  %..Expressions.. 
  fem.expr = {'Vinddens1', '-Axt*Wx(x,y,-flcoil_yc)-Ayt*Wy(x,y,-flcoil_yc)',... 
              'Vinddens2', '-Axt*Wx(x,y,flcoil_yc)-Ayt*Wy(x,y,flcoil_yc)'}; 
 
  % Global expression
  fem.globalexpr = {'Vline',    '28*sin(om*t)',...
                    'Rpre',      '5.8',...
                    'Rpost',     '1.3',...
                    'Tfault',    '45e-3',...
                    'Tsmooth',   '1e-3',... 
                    'Rline',     'Rpre - (Rpre-Rpost)*flc2hs(t-Tfault,Tsmooth)',...
                    'Vind1',     '2*flacNt/(accross)*Vind_null1',... 
                    'Vind2',     '2*flacNt/(accross)*Vind_null2',... 
                    'fluxle',    'Bzintle',... 
                    'fluxri',    'Bzintri',...
                    'Vindle',    'Bztimintle',... 
                    'Vindri',    'Bztimintri'}; 

  % Initialize mesh
  fem.mesh = meshinit(fem, 'hauto',8);

  if (0)
    meshplot(fem) 
    return 
  end 

  %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
  %%% First application mode: gen init guess for DC coil excitation   %%%
  %%% Linear core and zero current in AC winding                      %%% 
  %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

  clear appl
  appl.mode.class = 'QuasiStatics';
  appl.name = 'emqa';
  appl.module = 'ACDC';
  appl.gporder = 4;
  appl.cporder = 2;
  clear prop
  prop.elemdefault='Vec2';
  prop.analysis='static';
  prop.potential='A';
  appl.prop = prop;

  clear bnd
  bnd.eltype = {'V0','cont'};
  bnd.magtype = {'A0','cont'};
  bnd.ind = {[1:5,9,15,21,27,29,45,49,61,63,67,69],...
	     [6:8,10:14,16:20,22:26,28,30:44,46:48,50:60,62,64,65,68]}; 
  appl.bnd = bnd;

  clear equ
  % Subdomain labels: 1) Air,  2) AC coil 3) DC coil 4) Core 
  equ.mur = {1,'linmurfe',1,1,1,1};
  equ.Je = {{0;0;0},{0;0;0},...
            {'flIdc*fldcNt*Wx(x,y,-flcoil_yc)/(dc_fill*dccross)'; ...
             'flIdc*fldcNt*Wy(x,y,-flcoil_yc)/(dc_fill*dccross)';0},...
            {'-flIdc*fldcNt*Wx(x,y,flcoil_yc)/(dc_fill*dccross)'; ...
             '-flIdc*fldcNt*Wy(x,y,flcoil_yc)/(dc_fill*dccross)';0},...
            {0;0;0},{0;0;0}};
  equ.ind = {1,4,3,6,2,5};

  appl.equ = equ;
  fem.appl{1} = appl;
  fem.frame = {'ref'};
  fem.border = 1;
  clear units;
  units.basesystem = 'SI';
  fem.units = units;

  % ODE Settings
  clear ode
  ode.dim={'Itot'};
  ode.f={'0'};
  ode.init={'0'};
  ode.dinit={'0'};
  fem.ode=ode;
  clear units;
  units.basesystem = 'SI';
  ode.units = units;
 
  % Multiphysics
  fem=multiphysics(fem);

  % Extend mesh
  fem.xmesh=meshextend(fem);

  % Solve problem
  fprintf('  Stationary computation for linear core ... \n')
  fem.sol=femstatic(fem, ...
		  'solcomp',{'tAxAyAz20','tAxAyAz21','tAxAyAz10','psi'}, ...
		  'outcomp',{'tAxAyAz20','tAxAyAz21','tAxAyAz10','psi','Itot'}, ...
	          'linsolver','pardiso', ...
	          'errorchk','off');
  fprintf('  ... done! \n')

  %..Save fem for future reference 
  femdcstart = fem; 

%%%  return 

  %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
  %%% Second application mode: nonlinear DC coil                      %%%
  %%% Parametric solver for current in DC winding                     %%%
  %%% Zero current in the AC winding                                  %%% 
  %%% Generating initial guess for the transient simulation           %%% 
  %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
  clear appl								  
  appl.mode.class = 'QuasiStatics';					  
  appl.name = 'emqa';
  appl.module = 'ACDC';
  appl.gporder = 4;
  appl.cporder = 2;
  clear prop
  prop.elemdefault='Vec2';
  prop.analysis='transient';
  prop.potential='A';
  prop.gaugefix='on';
  appl.prop = prop;

  clear bnd
  bnd.eltype = {'V0','cont'};
  bnd.magtype = {'A0','cont'};
  bnd.ind = {[1:5,9,15,21,27,29,45,49,61,63,67,69],...
	     [6:8,10:14,16:20,22:26,28,30:44,46:48,50:60,62,64,65,68]}; 
  appl.bnd = bnd;

  clear equ
  % Subdomain labels: 1) Air,  2) AC coil 3) DC coil 4) Core 
  if (strcmp(bhswtch,'linear')==1)
    equ.mur = {1,'linmurfe',1,1,1,1};
  elseif (strcmp(bhswtch,'french')==1)
    equ.mur = {1,'murfe(sqrt(normB),bha,2*bhb,bhc),1,1,1,1'};
  elseif (strcmp(bhswtch,'german')==1)
    equ.mur = {1,'murfe2(normB,C1,C2)',1,1,1,1};
  elseif (strcmp(bhswtch,'german2')==1)    
    equ.mur = {1,'mur_a(normB,C1,C2)',1,1,1,1};
  elseif (strcmp(bhswtch,'dalibor')==1)
    equ.mur = {1,'bmurtabular(normB)',1,1,1,1};
  elseif (strcmp(bhswtch,'dl')==1)
    equ.mur = {1,'dlbhfct(normB)',1,1,1,1};
  else 
    error('  error::undefined BH switch')
  end
  equ.Je = {{0;0;0},{0;0;0},...
            {'flIdc*fldcNt*Wx(x,y,-flcoil_yc)/(dc_fill*dccross)'; ...
             'flIdc*fldcNt*Wy(x,y,-flcoil_yc)/(dc_fill*dccross)';0},...
            {'-flIdc*fldcNt*Wx(x,y,flcoil_yc)/(dc_fill*dccross)'; ...
             '-flIdc*fldcNt*Wy(x,y,flcoil_yc)/(dc_fill*dccross)';0},...	    
             {0;0;0},{0;0;0}};
  equ.ind = {1,4,3,6,2,5};

  appl.equ = equ;
  fem.appl{1} = appl;
  fem.frame = {'ref'};
  fem.border = 1;
  clear units;
  units.basesystem = 'SI';
  fem.units = units;

  % ODE Settings
  clear ode
  ode.dim={'Itot'};
  ode.f={'0'};
  ode.init={'0'};
  ode.dinit={'0'};
  fem.ode=ode;
  clear units;
  units.basesystem = 'SI';
  ode.units = units;

  % Multiphysics
  fem=multiphysics(fem);

  % Extend mesh
  fem.xmesh=meshextend(fem);

  % Solve problem
  fprintf('  Ramping current in DC coil ... \n') 
  atolv = 1e-3; psitol = 1e3*atolv; rtolv = 1e-3; 
  fem.sol=femtime(fem, ...
		  'solcomp',{'tAxAyAz20','tAxAyAz21','tAxAyAz10','psi'}, ...
		  'outcomp',{'tAxAyAz20','tAxAyAz21','tAxAyAz10','tAxAyAz20t','tAxAyAz21t','tAxAyAz10t','psi','Itot'}, ...
		  'tlist', [0:0.001:0.005], ...
		  'tout','tlist',...
		  'atol', {'tAxAyAz20',atolv,'tAxAyAz21',atolv,'tAxAyAz10',atolv,'psi',psitol,'Itot', 1e-1},...
	          'rtol', rtolv,...
                  'nlsolver','manual', ...
                  'ntolfact',0.01, ...
                  'maxiter',25, ...
                  'dtech','const', ...
                  'damp',1.0, ...
		  'jtech','minimal',...  
	          'linsolver','pardiso', ...
	          'errorchk','off');
  fprintf('  ... done! \n')

  femacstart = fem; 

%%%  return 

  %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%% 
  %%%% Third application mode: transient computation of the AC coil   %%% 
  %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%% 
  clear appl								  
  appl.mode.class = 'QuasiStatics';					  
  appl.name = 'emqa';
  appl.module = 'ACDC';
  appl.gporder = 4;
  appl.cporder = 2;
  clear prop
  prop.elemdefault='Vec2';
  prop.analysis='transient';
  prop.potential='A';
  prop.gaugefix='on';
  appl.prop = prop;

  clear bnd
  bnd.eltype = {'V0','cont'};
  bnd.magtype = {'A0','cont'};
  bnd.ind = {[1:5,9,15,21,27,29,45,49,61,63,67,69],...
	     [6:8,10:14,16:20,22:26,28,30:44,46:48,50:60,62,64,65,68]}; 
  appl.bnd = bnd;

  clear equ
  % Subdomain labels: 1) Air,  2) AC coil 3) DC coil 4) Core 
  if (strcmp(bhswtch,'linear')==1)
    equ.mur = {1,'linmurfe',1,1,1,1};
  elseif (strcmp(bhswtch,'french')==1)
    equ.mur = {1,'murfe(sqrt(normB),bha,2*bhb,bhc)',1,1,1,1};
  elseif (strcmp(bhswtch,'german')==1)
    equ.mur = {1,'murfe2(normB,C1,C2)',1,1,1,1};
  elseif (strcmp(bhswtch,'german2')==1)    
    equ.mur = {1,'mur_a(normB,C1,C2)',1,1,1,1};
  elseif (strcmp(bhswtch,'dalibor')==1)
    equ.mur = {1,'bmurtabular(normB)',1,1,1,1};
  elseif (strcmp(bhswtch,'dl')==1)
    equ.mur = {1,'dlbhfct(normB)',1,1,1,1};
  else 
    error('  error::undefined BH switch')
  end
  equ.Je = {{0;0;0},{0;0;0},...
            {'flIdc*fldcNt*Wx(x,y,-flcoil_yc)/(dc_fill*dccross)'; ...
             'flIdc*fldcNt*Wy(x,y,-flcoil_yc)/(dc_fill*dccross)';0},...
            {'-flIdc*fldcNt*Wx(x,y,flcoil_yc)/(dc_fill*dccross)'; ...
             '-flIdc*fldcNt*Wy(x,y,flcoil_yc)/(dc_fill*dccross)';0},...	    
            {'flacNt*Itot*Wx(x,y,-flcoil_yc)/(ac_fill*accross)'; ...
             'flacNt*Itot*Wy(x,y,-flcoil_yc)/(ac_fill*accross)';0},...
            {'flacNt*Itot*Wx(x,y,flcoil_yc)/(ac_fill*accross)'; ...
             'flacNt*Itot*Wy(x,y,flcoil_yc)/(ac_fill*accross)';0}};
  equ.ind = {1,4,3,6,2,5};

  appl.equ = equ;
  fem.appl{1} = appl;
  fem.frame = {'ref'};
  fem.border = 1;
  clear units;
  units.basesystem = 'SI';
  fem.units = units;

  % Coupling variable elements
  clear elemcpl
  % Integration coupling variables
  clear elem
  elem.elem = 'elcplscalar';
  elem.g = {'1'};
  src = cell(1,1);
  clear equ
  equ.expr = {{{},'Vinddens1',{},{}},{{},{},'Vinddens2',{}}};
  equ.ipoints = {{{},'4',{},{}},{{},{},'4',{}}};
  equ.frame = {{{},'ref','ref','ref'},{{},{},'ref',{}}};
  equ.ind = {{'1','3','4'},{'2'},{'5'},{'6'}};
  src{1} = {{},{},{},equ};
  elem.src = src;
  geomdim = cell(1,1);
  geomdim{1} = {};
  elem.geomdim = geomdim;
  elem.var = {'Vind_null1','Vind_null2'};
  elem.global = {'1','2'};
  elem.maxvars = {};
  elemcpl{1} = elem;
  fem.elemcpl = elemcpl;

  % ODE Settings
  clear ode
  ode.dim={'Itot'};
%%%  ode.f={'Itot-6.5*sin(om*t)'};
  ode.f={'Rline*Itot-Vind1+Vind2-Vline'};
  ode.init={'0'};
  ode.dinit={'0'};
  fem.ode=ode;
  clear units;
  units.basesystem = 'SI';
  ode.units = units;

  % Multiphysics
  fem=multiphysics(fem);

  % Extend mesh
  fem.xmesh=meshextend(fem);

  % Solve problem
  fprintf('  Transient computation for non-linear core ... \n')
  atolv = 1e-6; psitol = 1e3*atolv; rtolv = 1e-6; 
  fem.sol=femtime(fem, ...
		  'solcomp',{'tAxAyAz20','tAxAyAz21','tAxAyAz10','psi','Itot'}, ...
		  'outcomp',{'tAxAyAz20','tAxAyAz21','tAxAyAz10','tAxAyAz20t','tAxAyAz21t','tAxAyAz10t','psi','Itot'}, ...
		  'init', femacstart.sol, ... 
		  'tlist',[0:0.001:0.08], ...
		  'tout','tlist',...
		  'atol', {'tAxAyAz20',atolv,'tAxAyAz21',atolv,'tAxAyAz10',atolv,'psi',psitol,'Itot', 1e-1},...
	          'rtol', rtolv,...
                  'nlsolver','manual', ...
                  'ntolfact',0.01, ...
                  'maxiter',25, ...
                  'dtech','const', ...
                  'damp',1.0, ...
		  'jtech','minimal',...  
	          'linsolver','pardiso', ...
	          'errorchk','off');
  femac = fem; 

  postglobalplot(femac,'Itot')

  if (0) 
    % Plot solution
    postplot(fem, ...
	     'slicedata',{'normB','cont','internal','unit','T'}, ...
	     'slicexspacing',[0 0], ...
	     'sliceyspacing',0, ...
	     'slicezspacing',0, ...
	     'slicemap','jet(1024)', ...
	     'title','Linear Magnetic flux density, norm [T]', ...
	     'grid','on', ...
	     'campos',[1.4568704751417896,-2.5129859116254782,-0.3780279402053226], ...
	     'camtarget',[0.1775070304949263,0.17877995074715705,0.1743536360104538], ...
	     'camup',[-0.1431496464653533,-0.26378847351080165,0.953899271390688], ...
	     'camva',10.407148172765218);
  end 

